==> jc-1.4.0.tar.gz: gnu/xml/dom/DomEvent__24DomMutationEvent.h <==
// public final class gnu.xml.dom.DomEvent$DomMutationEvent

// class file dependencies
// @dep_class 1aca0886fa29dbb9 gnu_xml_dom_DomEvent
// @dep_class cfc3b0fe7749bc6f gnu_xml_dom_DomEvent__24DomMutationEvent
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomEvent

#include "gnu/xml/dom/DomEvent.h"

#ifndef _JC_gnu_xml_dom_DomEvent__24DomMutationEvent_H_
#define _JC_gnu_xml_dom_DomEvent__24DomMutationEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_refs	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_refs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_nonrefs	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$refs	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$refs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$nonrefs	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$nonrefs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object;

typedef const struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vmethods	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vmethods;
typedef const struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtable	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtable;
typedef const struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
extern jshort _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getAttrChange$9d3ca5dc572fe4ce(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getAttrName$b6a2e9550243ba67(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getNewValue$e05294ea41909d4b(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getPrevValue$e919dad3eb8fa826(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
extern struct _jc_object *_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getRelatedNode$b3d796f5322706c9(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
extern void _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$initMutationEvent$45663122e6d857a6(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jshort);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getAttrChange$9d3ca5dc572fe4ce;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getAttrName$b6a2e9550243ba67;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getNewValue$e05294ea41909d4b;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getPrevValue$e919dad3eb8fa826;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getRelatedNode$b3d796f5322706c9;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$initMutationEvent$45663122e6d857a6;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
	jshort	(*getAttrChange$9d3ca5dc572fe4ce)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
	struct _jc_java_lang_String$object	*(*getAttrName$b6a2e9550243ba67)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
	struct _jc_java_lang_String$object	*(*getNewValue$e05294ea41909d4b)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
	struct _jc_java_lang_String$object	*(*getPrevValue$e919dad3eb8fa826)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
	struct _jc_object	*(*getRelatedNode$b3d796f5322706c9)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *);
	void	(*initMutationEvent$45663122e6d857a6)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jshort);
};

// Vtable
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomEvent$vmethods	gnu_xml_dom_DomEvent;
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vmethods	gnu_xml_dom_DomEvent__24DomMutationEvent;
};

// Vtype
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_refs {
	struct _jc_object	*relatedNode;
	struct _jc_java_lang_String$object	*prevValue;
	struct _jc_java_lang_String$object	*newValue;
	struct _jc_java_lang_String$object	*attrName;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$refs {
    _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_refs	gnu_xml_dom_DomEvent__24DomMutationEvent;
    _jc_gnu_xml_dom_DomEvent$sub_refs	gnu_xml_dom_DomEvent;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_nonrefs {
	jshort	attrChange;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomEvent$sub_nonrefs	gnu_xml_dom_DomEvent;
    _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_nonrefs	gnu_xml_dom_DomEvent__24DomMutationEvent;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object {
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype	*vtype;
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomEvent__24DomMutationEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$class_object;

#endif	/* _JC_gnu_xml_dom_DomEvent__24DomMutationEvent_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomEvent__24DomMutationEvent.h <==
// public final class gnu.xml.dom.DomEvent$DomMutationEvent

// class file dependencies
// @dep_class 1aca0886fa29dbb9 gnu_xml_dom_DomEvent
// @dep_class cfc3b0fe7749bc6f gnu_xml_dom_DomEvent__24DomMutationEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomEvent

#include "gnu/xml/dom/DomEvent.h"

#ifndef _JC_gnu_xml_dom_DomEvent__24DomMutationEvent_H_
#define _JC_gnu_xml_dom_DomEvent__24DomMutationEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_refs	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_refs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_nonrefs	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$refs	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$refs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$nonrefs	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$nonrefs;
typedef struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object;

typedef const struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vmethods	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vmethods;
typedef const struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtable	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtable;
typedef const struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$_init$c31b894660454d13(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
extern jshort _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getAttrChange$9d3ca5dc572fe4ce(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getAttrName$b6a2e9550243ba67(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getNewValue$e05294ea41909d4b(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getPrevValue$e919dad3eb8fa826(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$getRelatedNode$b3d796f5322706c9(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method$initMutationEvent$45663122e6d857a6(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jshort) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getAttrChange$9d3ca5dc572fe4ce;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getAttrName$b6a2e9550243ba67;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getNewValue$e05294ea41909d4b;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getPrevValue$e919dad3eb8fa826;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$getRelatedNode$b3d796f5322706c9;
extern _jc_method _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$method_info$initMutationEvent$45663122e6d857a6;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
	jshort	(*getAttrChange$9d3ca5dc572fe4ce)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getAttrName$b6a2e9550243ba67)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getNewValue$e05294ea41909d4b)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPrevValue$e919dad3eb8fa826)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getRelatedNode$b3d796f5322706c9)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *) _JC_JCNI_ATTR;
	void	(*initMutationEvent$45663122e6d857a6)(_jc_env *, struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object *, struct _jc_java_lang_String$object *, jboolean, jboolean, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jshort) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomEvent$vmethods	gnu_xml_dom_DomEvent;
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vmethods	gnu_xml_dom_DomEvent__24DomMutationEvent;
};

// Vtype
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_refs {
	struct _jc_object	*relatedNode;
	struct _jc_java_lang_String$object	*prevValue;
	struct _jc_java_lang_String$object	*newValue;
	struct _jc_java_lang_String$object	*attrName;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$refs {
    _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_refs	gnu_xml_dom_DomEvent__24DomMutationEvent;
    _jc_gnu_xml_dom_DomEvent$sub_refs	gnu_xml_dom_DomEvent;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_nonrefs {
	jshort	attrChange;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomEvent$sub_nonrefs	gnu_xml_dom_DomEvent;
    _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$sub_nonrefs	gnu_xml_dom_DomEvent__24DomMutationEvent;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$object {
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype	*vtype;
	_jc_gnu_xml_dom_DomEvent__24DomMutationEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$vtype _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomEvent__24DomMutationEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomEvent__24DomMutationEvent$class_object;

#endif	/* _JC_gnu_xml_dom_DomEvent__24DomMutationEvent_H_ */
